<?php
/**
 * @file
 * Admin settings form for the PGP Contact Forms module
 */

/**
 * Settings form for admin section
 */
function pgp_contact_settings() {
  $form = array();

  $form['pgp_contact_library_path'] = array(
    '#type' => 'textfield',
    '#title' => t('Path to libraries'),
    '#default_value' => variable_get('pgp_contact_library_path', 'sites/all/libraries'),
    '#size' => 128,
    '#maxlength' => 128,
    '#description' => t("Path to encrytion libraries downloaded from !link.", array('!link' => l('www.hanewin.net/encrypt', 'http://www.hanewin.net/encrypt/'))),
    '#required' => TRUE,
  );

  $form['pgp_contact_securepages'] = array(
    '#type' => 'checkbox',
    '#title' => t('Force SSL on all contact pages and key upload pages.'),
    '#default_value' => variable_get('pgp_contact_securepages', 0),
    '#description' => t("Requires the !securepages module. This will override Secure Pages settings. Make sure to !enablelink, too.", array(
      '!securepages' => l(t('Secure Pages'), 'http://drupal.org/project/securepages'),
      '!enablelink' => l(t('enable Secure Pages'), 'admin/build/securepages'),
      )),
    '#required' => FALSE,
    '#disabled' => TRUE,
  );
  // Only enable the force SSL option if securepages is enabled on the site
  if (module_exists('securepages')) {
    $form['pgp_contact_securepages']['#disabled'] = FALSE;
    $form['#submit'][] = 'pgp_contact_force_ssl';
  }

  $form['pgp_contact_policy_wrapper'] = _pgp_contact_policy_field('pgp_contact_sitewide_policy');

  $form['pgp_contact_policy_wrapper']['pgp_contact_sitewide_policy']['#options'] = array(
    'user' => t('Allow individual policies per form.'),
    'always' => t('Force encryption on this site for all forms with public keys assigned to them.'),

  );

  $form['tradeoff_features'] = array(
    '#tree' => FALSE,
    '#type' => 'fieldset',
    '#title' => t('Trade-Offs'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );

  $form['tradeoff_features']['intro_text'] = array(
    '#value' => '<p>' . t('These features can compromise the security of encrypted data sent via forms, but can be convenient for certain use cases.') . '</p>',
    '#type' => 'markup',
  );

  $form['tradeoff_features']['pgp_contact_anon_contact'] = array(
    '#type' => 'checkbox',
    '#title' => t('Allow anonymous visitors to contact users.'),
    '#default_value' => variable_get('pgp_contact_anon_contact', 0),
    '#description' => t("This will override the core contact module's permissions check for using the user contact form."),
    '#required' => FALSE,
  );

  $form['tradeoff_features']['pgp_contact_disable_ssl_check'] = array(
    '#type' => 'checkbox',
    '#title' => t('Hide the unsecured connection warning'),
    '#default_value' => variable_get('pgp_contact_disable_ssl_check', 0),
    '#description' => t("This will hide the unsecured connection warning on contact forms. A better way of dealing with this problem is to use SSL on your site."),
    '#required' => FALSE,
  );

  $form['#submit'][] = 'pgp_contact_set_policy';

  return system_settings_form($form);
}

/**
 * Set policies for all keys on a submission of always for the sitewide policy
 */
function pgp_contact_set_policy ($form, &$form_state) {
  if ($form_state['values']['pgp_contact_sitewide_policy'] == 'always') {
    db_query('UPDATE {pgp_contact_pub_keys} SET policy = "always"');
    drupal_set_message(t('All public keys set to force encryption.'), 'warning');
  }
}

/**
 * Validate that the settings path allows us access to the right libraries
 */
function pgp_contact_settings_validate($form, &$form_state) {
  $files = file_scan_directory("./{$form_state['values']['pgp_contact_library_path']}", '\.js$', array('.', '..', 'CVS'), 0, FALSE);
  $check = '_';
  if ($files) { 
    sort($files); 
    // Run through the files and add values as needed 
    foreach ($files as $file) { 
      $found = FALSE; 
      switch ($file->name) { 
        case 'PGencode': 
          $check .= '1'; 
          drupal_set_message(t('@file has been found.', array('@file' => $file->basename))); 
          break; 
        case 'PGpubkey': 
          $check .= '2'; 
          drupal_set_message(t('@file has been found.', array('@file' => $file->basename))); 
          break; 
        case 'aes-enc': 
          $check .= '3'; 
          drupal_set_message(t('@file has been found.', array('@file' => $file->basename))); 
          break; 
        case 'base64': 
          $check .= '4'; 
          drupal_set_message(t('@file has been found.', array('@file' => $file->basename))); 
          break; 
        case 'mouse': 
          $check .= '5'; 
          drupal_set_message(t('@file has been found.', array('@file' => $file->basename))); 
          break; 
        case 'rsa': 
          $check .= '6'; 
          drupal_set_message(t('@file has been found.', array('@file' => $file->basename))); 
          break; 
        case 'sha1': 
          $check .= '7'; 
          drupal_set_message(t('@file has been found.', array('@file' => $file->basename))); 
          break; 
        default: 
          $check .= '_'; 
          break; 
      } 
    } 
  } 
  if ($check == '_1234567') { 
    return true; 
  } 
  else { 
    form_set_error('pgp_contact_library_path', 'Some or all files are missing from this directory.'); 
    watchdog('pgp_contact', 'Settings error, file pattern was @check', array('@check' => $check), WATCHDOG_WARNING); 
  } 
}
